@@ -22,9 +22,10 @@ from bmt.utils import format_element, parse_name
 Url = str
 Path = str
 
-REMOTE_PATH = "https://raw.githubusercontent.com/biolink/biolink-model/v3.2.3/biolink-model.yaml"
-PREDICATE_MAP = 'https://raw.githubusercontent.com/biolink/biolink-model/v3.2.3/predicate_mapping.yaml'
-INFORES_MAP = 'https://raw.githubusercontent.com/biolink/biolink-model/v3.2.3/infores_catalog_nodes.tsv'
+REMOTE_PATH = "https://raw.githubusercontent.com/biolink/biolink-model/v3.2.6/biolink-model.yaml"
+PREDICATE_MAP = 'https://raw.githubusercontent.com/biolink/biolink-model/v3.2.6/predicate_mapping.yaml'
+INFORES_MAP = 'https://raw.githubusercontent.com/biolink/biolink-model/v3.2.6/infores_catalog_nodes.tsv'
+
 
 NODE_PROPERTY = "node property"
 ASSOCIATION_SLOT = "association slot"
@@ -1096,6 +1097,26 @@ class Toolkit(object):
         """
         return RELATED_TO in self.get_ancestors(name, mixin)
 
+    @lru_cache(CACHE_SIZE)
+    def get_denormalized_association_slots(self, formatted) -> List[Element]:
+        """
+        Gets all association slots that are denormalized
+
+        Returns
+        -------
+        List[linkml_model.meta.Element]
+            A list of association slots
+
+        """
+        slots = []
+        for k, v in self.view.schema.slots.items():
+            if v.annotations and "denormalized" in v.annotations:
+                if formatted:
+                    slots.append(format_element(v))
+                else:
+                    slots.append(k)
+        return slots
+
     @lru_cache(CACHE_SIZE)
     def is_translator_canonical_predicate(self, name: str, mixin: bool = True) -> bool:
         """
